{% extends "automations/base.html" %}{% load i18n %} {% block content_automations %}{% spaceless %}

# {{ automation.get_automation_class.get_verbose_name }} {{ automation.automation_class }}

- {% trans "Automation id:" %} {{ automation.id }}
- {% trans "Updated:" %} {{ automation.updated }}
- {% trans "Paused until:" %} {{ automation.paused_until }}
- {% trans "Created:" %} {{ automation.created }}

{% if automation.data %}

### {% trans "Data" %}

    {{ automation.data }}

{% endif %}
{% include "automations/includes/history.html" with tasks=tasks %} {% endspaceless %} {% endblock %}